@@ -23,14 +23,11 @@ class ComposedLink(TerminatingLink):
 
         self.links[-1](rath)  # last one gets only rath
 
-    async def aconnect(self):
-        return await asyncio.gather(*[link.aconnect() for link in self.links])
-
     async def aquery(self, operation: Operation):
         return await self.first_link.aquery(operation)
 
     async def asubscribe(self, operation: Operation):
-        for result in await self.first_link.asubscribe(operation):
+        async for result in self.first_link.asubscribe(operation):
             yield result
 
     def query(self, operation: Operation):
