@@ -4,7 +4,7 @@ from rath.operation import Operation
 from rath.links.base import TerminatingLink
 
 
-class SplitTransport(TerminatingLink):
+class SplitLink(TerminatingLink):
     def __init__(
         self,
         left: TerminatingLink,
@@ -13,19 +13,15 @@ class SplitTransport(TerminatingLink):
     ) -> None:
         super().__init__()
         assert isinstance(left, TerminatingLink), "left must be a TerminatingLink"
-        assert isinstance(right, TerminatingLink), "left must be a TerminatingLink"
+        assert isinstance(right, TerminatingLink), "right must be a TerminatingLink"
         self.left = left
         self.right = right
         self.split = split
 
-    async def __call__(self, rath):
+    def __call__(self, rath):
         self.left(rath)
         self.right(rath)
 
-    async def aconnect(self) -> None:
-        await self.left.aconnect()
-        await self.right.aconnect()
-
     async def aquery(self, operation: Operation) -> Operation:
         future = (
             self.left.aquery(operation)
@@ -71,4 +67,4 @@ def split(
     Splits a Link into two paths. Acording to a predicate function. If predicate returns
     true, the operation is sent to the left path, otherwise to the right path.
     """
-    return SplitTransport(left, right, split)
+    return SplitLink(left, right, split)
